@@ -4,7 +4,7 @@ from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel
 
-from ..core import BaseClient, limit_concurrency
+from ..core import BaseClient, with_concurrency_limit
 from ..encoders import encode_query_params
 
 PATH = "/users/{user_uuid}/accounts/{account_uuid}/alerts"
@@ -92,7 +92,7 @@ class BaseAlertsResource:
                 for page in range(max_pages - 1)
             ]
             response_pages = await asyncio.gather(
-                *limit_concurrency(coroutines, self._client.concurrency_limit)
+                *with_concurrency_limit(coroutines, self._client.concurrency_limit)
             )
             responses = (response, *response_pages)
         else:
